import shutil
import subprocess

AUTOSCALER_HELM_REPO_NAME = "autoscaler"
AUTOSCALER_HELM_REPO_URL = "https://kubernetes.github.io/autoscaler"
AUTOSCALER_HELM_CHART = "cluster-autoscaler"
AUTOSCALER_HELM_VERSION = "9.27.0"


def setup_helm_repository(name, url):
    subprocess.run(["helm", "repo", "add", name, url])
    subprocess.run(["helm", "repo", "update"])


def download_helm_chart(repo, chart, version):
    shutil.rmtree(f"magnum_cluster_api/charts/{chart}", ignore_errors=True)
    subprocess.run(
        [
            "helm",
            "fetch",
            f"{repo}/{chart}",
            "--version",
            version,
            "--untar",
            "--untardir",
            "magnum_cluster_api/charts",
        ]
    )


def download_autoscaler_chart():
    setup_helm_repository(AUTOSCALER_HELM_REPO_NAME, AUTOSCALER_HELM_REPO_URL)
    download_helm_chart(
        AUTOSCALER_HELM_REPO_NAME, AUTOSCALER_HELM_CHART, AUTOSCALER_HELM_VERSION
    )
    with open("hack/add-omt-to-clusterrole.patch", "rb", 0) as fd:
        subprocess.check_call(
            [
                "patch",
                "-p0",
            ],
            cwd=f"magnum_cluster_api/charts/{AUTOSCALER_HELM_CHART}/templates",
            stdin=fd,
        )


if __name__ == "__main__":
    download_autoscaler_chart()



# Copyright (c) 2023 VEXXHOST, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_config import cfg

auto_scaling_opts = [
    cfg.StrOpt(
        "image_repository",
        default="registry.k8s.io/autoscaling",
        help="Image repository for the cluster auto-scaler.",
    ),
    cfg.StrOpt(
        "v1_22_image",
        default="$image_repository/cluster-autoscaler:v1.22.1",
        help="Image for the cluster auto-scaler for Kubernetes v1.22.",
    ),
    cfg.StrOpt(
        "v1_23_image",
        default="$image_repository/cluster-autoscaler:v1.23.0",
        help="Image for the cluster auto-scaler for Kubernetes v1.23.",
    ),
    cfg.StrOpt(
        "v1_24_image",
        default="$image_repository/cluster-autoscaler:v1.24.1",
        help="Image for the cluster auto-scaler for Kubernetes v1.24.",
    ),
    cfg.StrOpt(
        "v1_25_image",
        default="$image_repository/cluster-autoscaler:v1.25.1",
        help="Image for the cluster auto-scaler for Kubernetes v1.25.",
    ),
    cfg.StrOpt(
        "v1_26_image",
        default="$image_repository/cluster-autoscaler:v1.26.1",
        help="Image for the cluster auto-scaler for Kubernetes v1.26.",
    ),
]

CONF = cfg.CONF
CONF.register_opts(auto_scaling_opts, "auto_scaling")
